import { z } from 'zod';
/**
 * Expected key that auth output is stored under
 */
export declare const authOutputKey = "authOutput";
/**
 * Expected key that graphql output is stored under
 */
export declare const graphqlOutputKey = "graphqlOutput";
/**
 * Expected key that storage output is stored under
 */
export declare const storageOutputKey = "storageOutput";
/**
 * Defines the unified expected shape of Amplify backend output.
 * As new constructs are added that need to contribute backend output, entries should be added here so that client config generation is aware of these outputs
 */
export declare const unifiedBackendOutputSchema: z.ZodObject<{
    authOutput: z.ZodOptional<z.ZodDiscriminatedUnion<"version", [z.ZodObject<{
        version: z.ZodLiteral<"1">;
        payload: z.ZodObject<{
            userPoolId: z.ZodString;
            webClientId: z.ZodString;
            authRegion: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            userPoolId: string;
            webClientId: string;
            authRegion: string;
        }, {
            userPoolId: string;
            webClientId: string;
            authRegion: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        version: "1";
        payload: {
            userPoolId: string;
            webClientId: string;
            authRegion: string;
        };
    }, {
        version: "1";
        payload: {
            userPoolId: string;
            webClientId: string;
            authRegion: string;
        };
    }>]>>;
    graphqlOutput: z.ZodOptional<z.ZodDiscriminatedUnion<"version", [z.ZodObject<{
        version: z.ZodLiteral<"1">;
        payload: z.ZodObject<{
            awsAppsyncRegion: z.ZodString;
            awsAppsyncApiEndpoint: z.ZodString;
            awsAppsyncAuthenticationType: z.ZodEnum<["API_KEY", "AWS_LAMBDA", "AWS_IAM", "OPENID_CONNECT", "AMAZON_COGNITO_USER_POOLS"]>;
            awsAppsyncApiKey: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            awsAppsyncRegion: string;
            awsAppsyncApiEndpoint: string;
            awsAppsyncAuthenticationType: "API_KEY" | "AWS_LAMBDA" | "AWS_IAM" | "OPENID_CONNECT" | "AMAZON_COGNITO_USER_POOLS";
            awsAppsyncApiKey?: string | undefined;
        }, {
            awsAppsyncRegion: string;
            awsAppsyncApiEndpoint: string;
            awsAppsyncAuthenticationType: "API_KEY" | "AWS_LAMBDA" | "AWS_IAM" | "OPENID_CONNECT" | "AMAZON_COGNITO_USER_POOLS";
            awsAppsyncApiKey?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        version: "1";
        payload: {
            awsAppsyncRegion: string;
            awsAppsyncApiEndpoint: string;
            awsAppsyncAuthenticationType: "API_KEY" | "AWS_LAMBDA" | "AWS_IAM" | "OPENID_CONNECT" | "AMAZON_COGNITO_USER_POOLS";
            awsAppsyncApiKey?: string | undefined;
        };
    }, {
        version: "1";
        payload: {
            awsAppsyncRegion: string;
            awsAppsyncApiEndpoint: string;
            awsAppsyncAuthenticationType: "API_KEY" | "AWS_LAMBDA" | "AWS_IAM" | "OPENID_CONNECT" | "AMAZON_COGNITO_USER_POOLS";
            awsAppsyncApiKey?: string | undefined;
        };
    }>]>>;
    storageOutput: z.ZodOptional<z.ZodDiscriminatedUnion<"version", [z.ZodObject<{
        version: z.ZodLiteral<"1">;
        payload: z.ZodObject<{
            bucketName: z.ZodString;
            storageRegion: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            bucketName: string;
            storageRegion: string;
        }, {
            bucketName: string;
            storageRegion: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        version: "1";
        payload: {
            bucketName: string;
            storageRegion: string;
        };
    }, {
        version: "1";
        payload: {
            bucketName: string;
            storageRegion: string;
        };
    }>]>>;
}, "strip", z.ZodTypeAny, {
    authOutput?: {
        version: "1";
        payload: {
            userPoolId: string;
            webClientId: string;
            authRegion: string;
        };
    } | undefined;
    graphqlOutput?: {
        version: "1";
        payload: {
            awsAppsyncRegion: string;
            awsAppsyncApiEndpoint: string;
            awsAppsyncAuthenticationType: "API_KEY" | "AWS_LAMBDA" | "AWS_IAM" | "OPENID_CONNECT" | "AMAZON_COGNITO_USER_POOLS";
            awsAppsyncApiKey?: string | undefined;
        };
    } | undefined;
    storageOutput?: {
        version: "1";
        payload: {
            bucketName: string;
            storageRegion: string;
        };
    } | undefined;
}, {
    authOutput?: {
        version: "1";
        payload: {
            userPoolId: string;
            webClientId: string;
            authRegion: string;
        };
    } | undefined;
    graphqlOutput?: {
        version: "1";
        payload: {
            awsAppsyncRegion: string;
            awsAppsyncApiEndpoint: string;
            awsAppsyncAuthenticationType: "API_KEY" | "AWS_LAMBDA" | "AWS_IAM" | "OPENID_CONNECT" | "AMAZON_COGNITO_USER_POOLS";
            awsAppsyncApiKey?: string | undefined;
        };
    } | undefined;
    storageOutput?: {
        version: "1";
        payload: {
            bucketName: string;
            storageRegion: string;
        };
    } | undefined;
}>;
/**
 * This type is a subset of the BackendOutput type that is exposed by the platform.
 * It represents BackendOutput that has been validated against the schema of known output values
 */
export type UnifiedBackendOutput = z.infer<typeof unifiedBackendOutputSchema>;
//# sourceMappingURL=index.d.ts.map